@@ -203,6 +203,9 @@ INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
 # 请求参数不合法。
 INVALIDPARAMETER_PAYLOAD = 'InvalidParameter.Payload'
 
+# 请求大小超限。
+INVALIDPARAMETER_REQUESTTOOLARGE = 'InvalidParameter.RequestTooLarge'
+
 # RoleCheck 传参有误。
 INVALIDPARAMETER_ROLECHECK = 'InvalidParameter.RoleCheck'
 
@@ -560,6 +563,9 @@ LIMITEXCEEDED_ALIAS = 'LimitExceeded.Alias'
 # Cdn使用超过最大限制。
 LIMITEXCEEDED_CDN = 'LimitExceeded.Cdn'
 
+# 用户开启镜像加速函数版本超限。
+LIMITEXCEEDED_CONTAINERIMAGEACCELERATEQUOTA = 'LimitExceeded.ContainerImageAccelerateQuota'
+
 # eip资源超限。
 LIMITEXCEEDED_EIP = 'LimitExceeded.Eip'
 
