@@ -102,7 +102,7 @@ class CodeBatch(AbstractModel):
         :param ProductName: 产品名称
 注意：此字段可能返回 null，表示取不到有效值。
         :type ProductName: str
-        :param Ext: 0
+        :param Ext: 未使用
 注意：此字段可能返回 null，表示取不到有效值。
         :type Ext: :class:`tencentcloud.trp.v20210515.models.Ext`
         :param TplName: 模板名称
@@ -198,6 +198,8 @@ class CreateCodeBatchRequest(AbstractModel):
         :type BatchId: str
         :param Remark: 备注
         :type Remark: str
+        :param MpTpl: 活动ID
+        :type MpTpl: str
         """
         self.CorpId = None
         self.MerchantId = None
@@ -205,6 +207,7 @@ class CreateCodeBatchRequest(AbstractModel):
         self.BatchType = None
         self.BatchId = None
         self.Remark = None
+        self.MpTpl = None
 
 
     def _deserialize(self, params):
@@ -214,6 +217,7 @@ class CreateCodeBatchRequest(AbstractModel):
         self.BatchType = params.get("BatchType")
         self.BatchId = params.get("BatchId")
         self.Remark = params.get("Remark")
+        self.MpTpl = params.get("MpTpl")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -592,6 +596,10 @@ class CreateTraceDataRequest(AbstractModel):
         :type TraceId: str
         :param TraceItems: 溯源信息
         :type TraceItems: list of TraceItem
+        :param Status: 溯源状态 0: 无效, 1: 有效
+        :type Status: int
+        :param PhaseData: 环节数据
+        :type PhaseData: :class:`tencentcloud.trp.v20210515.models.PhaseData`
         """
         self.CorpId = None
         self.BatchId = None
@@ -602,6 +610,8 @@ class CreateTraceDataRequest(AbstractModel):
         self.Type = None
         self.TraceId = None
         self.TraceItems = None
+        self.Status = None
+        self.PhaseData = None
 
 
     def _deserialize(self, params):
@@ -619,6 +629,10 @@ class CreateTraceDataRequest(AbstractModel):
                 obj = TraceItem()
                 obj._deserialize(item)
                 self.TraceItems.append(obj)
+        self.Status = params.get("Status")
+        if params.get("PhaseData") is not None:
+            self.PhaseData = PhaseData()
+            self.PhaseData._deserialize(params.get("PhaseData"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1602,11 +1616,20 @@ class ModifyCodeBatchRequest(AbstractModel):
         :type Status: int
         :param MpTpl: 模板ID
         :type MpTpl: str
+        :param MerchantId: 商户ID
+        :type MerchantId: str
+        :param ProductId: 商品ID
+        :type ProductId: str
+        :param Remark: 备注
+        :type Remark: str
         """
         self.BatchId = None
         self.CorpId = None
         self.Status = None
         self.MpTpl = None
+        self.MerchantId = None
+        self.ProductId = None
+        self.Remark = None
 
 
     def _deserialize(self, params):
@@ -1614,6 +1637,9 @@ class ModifyCodeBatchRequest(AbstractModel):
         self.CorpId = params.get("CorpId")
         self.Status = params.get("Status")
         self.MpTpl = params.get("MpTpl")
+        self.MerchantId = params.get("MerchantId")
+        self.ProductId = params.get("ProductId")
+        self.Remark = params.get("Remark")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1918,8 +1944,10 @@ class ModifyTraceDataRequest(AbstractModel):
         :type ChainData: :class:`tencentcloud.trp.v20210515.models.ChainData`
         :param CorpId: 企业ID
         :type CorpId: int
-        :param Status: [无效] 溯源状态
+        :param Status: 溯源状态 0: 无效, 1: 有效
         :type Status: int
+        :param PhaseData: 环节数据
+        :type PhaseData: :class:`tencentcloud.trp.v20210515.models.PhaseData`
         """
         self.TraceId = None
         self.BatchId = None
@@ -1937,6 +1965,7 @@ class ModifyTraceDataRequest(AbstractModel):
         self.ChainData = None
         self.CorpId = None
         self.Status = None
+        self.PhaseData = None
 
 
     def _deserialize(self, params):
@@ -1963,6 +1992,9 @@ class ModifyTraceDataRequest(AbstractModel):
             self.ChainData._deserialize(params.get("ChainData"))
         self.CorpId = params.get("CorpId")
         self.Status = params.get("Status")
+        if params.get("PhaseData") is not None:
+            self.PhaseData = PhaseData()
+            self.PhaseData._deserialize(params.get("PhaseData"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2025,6 +2057,50 @@ class PackSpec(AbstractModel):
         
 
 
+class PhaseData(AbstractModel):
+    """环节数据
+
+    """
+
+    def __init__(self):
+        r"""
+        :param HeadEnabled: 启用头
+        :type HeadEnabled: bool
+        :param HeadTitle: 标题
+        :type HeadTitle: str
+        :param Key: 标识符
+        :type Key: str
+        :param AppId: 小程序AppId
+        :type AppId: str
+        :param AppPath: 小程序AppPath
+        :type AppPath: str
+        :param AppName: 小程序名称AppName
+        :type AppName: str
+        """
+        self.HeadEnabled = None
+        self.HeadTitle = None
+        self.Key = None
+        self.AppId = None
+        self.AppPath = None
+        self.AppName = None
+
+
+    def _deserialize(self, params):
+        self.HeadEnabled = params.get("HeadEnabled")
+        self.HeadTitle = params.get("HeadTitle")
+        self.Key = params.get("Key")
+        self.AppId = params.get("AppId")
+        self.AppPath = params.get("AppPath")
+        self.AppName = params.get("AppName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Product(AbstractModel):
     """商品信息
 
@@ -2280,6 +2356,9 @@ class TraceItem(AbstractModel):
         :param Values: 多个值
 注意：此字段可能返回 null，表示取不到有效值。
         :type Values: list of str
+        :param Key: 类型标识
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Key: str
         """
         self.Name = None
         self.Value = None
@@ -2287,6 +2366,7 @@ class TraceItem(AbstractModel):
         self.ReadOnly = None
         self.Hidden = None
         self.Values = None
+        self.Key = None
 
 
     def _deserialize(self, params):
@@ -2296,6 +2376,7 @@ class TraceItem(AbstractModel):
         self.ReadOnly = params.get("ReadOnly")
         self.Hidden = params.get("Hidden")
         self.Values = params.get("Values")
+        self.Key = params.get("Key")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
